find_embedded

Function find_embedded 

pub fn find_embedded() -> Option<String>
Searches the running binary’s own bytes for an embedded rl program.

Returns Some(source) if this binary was produced by rl package, or None if it is a plain rl binary.